==> manaplus-1.1.3.20.tar.bz2: manaplus/src/net/manaserv/buysellhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_MANASERV_BUYSELLHANDLER_H
#define NET_MANASERV_BUYSELLHANDLER_H

#include "net/manaserv/messagehandler.h"

#include "net/buysellhandler.h"

#ifdef __GNUC__
#define _UNUSED_  __attribute__ ((unused))
#else
#define _UNUSED_
#endif

namespace ManaServ
{

class BuySellHandler : public MessageHandler, public Net::BuySellHandler
{
    public:
        BuySellHandler();

        void handleMessage(Net::MessageIn &msg);

        void requestSellList(std::string nick);

        void requestBuyList(std::string nick);

        void sendBuyRequest(std::string nick, ShopItem* item, int amount);

        void sendSellRequest(std::string nick, ShopItem* item, int amount);

};

} // namespace ManaServ

#endif

==> manaplus-1.1.8.21.tar.bz2: manaplus/src/net/manaserv/buysellhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_MANASERV_BUYSELLHANDLER_H
#define NET_MANASERV_BUYSELLHANDLER_H

#include "net/manaserv/messagehandler.h"

#include "net/buysellhandler.h"

#ifdef __GNUC__
#define A_UNUSED  __attribute__ ((unused))
#else
#define A_UNUSED
#endif

namespace ManaServ
{

class BuySellHandler : public MessageHandler, public Net::BuySellHandler
{
    public:
        BuySellHandler();

        void handleMessage(Net::MessageIn &msg);

        void requestSellList(std::string nick);

        void requestBuyList(std::string nick);

        void sendBuyRequest(std::string nick, ShopItem* item, int amount);

        void sendSellRequest(std::string nick, ShopItem* item, int amount);

};

} // namespace ManaServ

#endif
